# LM Identifier

With a surge of generative pretrained language models, it is becoming increasingly important to distinguish between human and AI-generated text. Inspired by [GPTZero](https://etedward-gptzero-main-zqgfwb.streamlit.app), an app that seeks to detect AI-generated text, LM Identifier pokes at this question even further by providing a growing suite of tools to help identify *which (publicly available) language model* might have been used to generate some given chunck of text.

## Installation

LM Identifier is available on PyPI.

```
$ pip install lm-identifier
```

To develop locally, first install pre-commit:

```
$ pip install --upgrade pip wheel
$ pip install pre-commit
$ pre-commit install
```

Install the package in editable mode.

```
pip install -e .
```

## Usages

WIP
